@@ -37,6 +37,12 @@ LOGGER = logging.getLogger(__name__)
 FUNCTION_NAMESPACE_DOCSTRING = """
     Namespace for functions. Functions are computations using objects
     created from the `types` namespace.
+
+    Boulder Opal also provides toolkits to simplify the workflow for common computation tasks.
+    Some toolkits host functions that you can access from their namespaces of
+    the :py:obj:`~qctrl.Qctrl` object.
+    See the `reference <https://docs.q-ctrl.com/boulder-opal/references/qctrl/Toolkits.html>`_
+    for details.
 """
 
 
